@@ -8,6 +8,14 @@ import runner1c.commands.dump_epf
 import runner1c.common as common
 import runner1c.exit_code
 
+_HASH_FILE = 'hash.txt'
+_FEATURE_BINARY = '.data'
+_FEATURE_SRC = '.feature'
+_EPF_BINARY = '.epf'
+_ERF_BINARY = '.erf'
+_DATA_SRC = '.xml'
+_BINARY_FOLDER = 'build'
+
 
 class SyncParser(runner1c.parser.Parser):
     @property
@@ -25,8 +33,8 @@ class SyncParser(runner1c.parser.Parser):
         self.add_argument_to_parser(connection_required=False)
         self._parser.add_argument('--create', action='store_const', const=True, help='создать бинарники из исходников')
         self._parser.add_argument('--folder', required=True, help='путь к папке репозитория')
-        self._parser.add_argument('--include', help='путь к папке, из которой нужно собрать бинарники')
-        self._parser.add_argument('--exclude', help='путь к папке, которую нужно пропустить')
+        self._parser.add_argument('--include', help='путь к папкам, из которых нужно собрать бинарники (через ,)')
+        self._parser.add_argument('--exclude', help='путь к папкам, которые нужно пропустить (через ,)')
         self._parser.add_argument('--hash_file', help='файл с хэшем бинарников для проверки изменений')
         self._parser.add_argument('--clear_hash', action='store_const', const=True,
                                   help='удалить старый файл с хэшем бинарников')
@@ -54,7 +62,7 @@ class Sync(runner1c.command.Command):
             try:
                 source_map = self._get_source()
                 for path_source, path_binary in source_map.items():
-                    if path_binary.endswith('.feature'):
+                    if path_binary.endswith(_FEATURE_SRC):
                         common.create_path(os.path.dirname(path_binary))
                         shutil.copy(path_source, path_binary)
                     else:
@@ -73,7 +81,7 @@ class Sync(runner1c.command.Command):
         else:
 
             for path_binary, path_source in self._get_change_binary().items():
-                if path_binary.endswith('.feature'):
+                if path_binary.endswith(_FEATURE_SRC):
                     common.create_path(os.path.dirname(path_source))
                     shutil.copy(path_binary, path_source)
                 else:
@@ -99,21 +107,12 @@ class Sync(runner1c.command.Command):
 
         return result_code
 
-    @property
-    def _binary_folder(self):
-        return 'build'
-
-    @property
-    def _feature_binary(self):
-        return '.data'
-
     @property
     def _hash_file_name(self):
         if getattr(self.arguments, 'hash_file', False):
             result = self.arguments.hash_file
         else:
-            file_name = 'hash.txt'
-            result = os.path.join(self.arguments.folder, self._binary_folder, file_name)
+            result = os.path.join(self.arguments.folder, _BINARY_FOLDER, _HASH_FILE)
 
         return result
 
@@ -127,45 +126,46 @@ class Sync(runner1c.command.Command):
         source_map = {}
 
         if getattr(self.arguments, 'include', False):
-            folder_for_walk = self.arguments.include
+            folder_for_walk = self.arguments.include.split(',')
         else:
-            folder_for_walk = self.arguments.folder
+            folder_for_walk = [self.arguments.folder]
 
         exclude_full_path = None
         if getattr(self.arguments, 'exclude', False):
-            exclude_full_path = self.arguments.exclude
+            exclude_full_path = self.arguments.exclude.split(',')
 
-        for root, dirs, files in os.walk(folder_for_walk, topdown=True):
-            dirs[:] = [d for d in dirs if d not in exclude and
-                       (True if exclude_full_path is None else os.path.join(root, d) != exclude_full_path)]
-            for file in files:
+        for path in folder_for_walk:
+            for root, dirs, files in os.walk(path, topdown=True):
+                dirs[:] = [d for d in dirs if d not in exclude and
+                           (True if exclude_full_path is None else os.path.join(root, d) not in exclude_full_path)]
+                for file in files:
 
-                if not file.endswith('.xml') and not file.endswith(self._feature_binary):
-                    continue
+                    if not file.endswith(_DATA_SRC) and not file.endswith(_FEATURE_BINARY):
+                        continue
 
-                path_source = os.path.join(root, file)
-                path_binary = os.path.join(self.arguments.folder,
-                                           self._binary_folder,
-                                           root.replace(self.arguments.folder + '\\', ''),
-                                           file)
-                if file.endswith('.xml'):
-                    if _is_header_epf(path_source):
-                        source_map[path_source] = path_binary.replace('.xml', '.epf')
-                    elif _is_header_erf(path_source):
-                        source_map[path_source] = path_binary.replace('.xml', '.erf')
-                elif file.endswith(self._feature_binary):
-                    source_map[path_source] = path_binary.replace(self._feature_binary, '.feature')
+                    path_source = os.path.join(root, file)
+                    path_binary = os.path.join(self.arguments.folder,
+                                               _BINARY_FOLDER,
+                                               root.replace(self.arguments.folder + '\\', ''),
+                                               file)
+                    if file.endswith(_DATA_SRC):
+                        if _is_header_epf(path_source):
+                            source_map[path_source] = path_binary.replace(_DATA_SRC, _EPF_BINARY)
+                        elif _is_header_erf(path_source):
+                            source_map[path_source] = path_binary.replace(_DATA_SRC, _ERF_BINARY)
+                    elif file.endswith(_FEATURE_BINARY):
+                        source_map[path_source] = path_binary.replace(_FEATURE_BINARY, _FEATURE_SRC)
 
         return source_map
 
     def _fill_files_hash(self, files):
         for file_name in files:
-            full_path = os.path.join(self.arguments.folder, self._binary_folder, file_name)
+            full_path = os.path.join(self.arguments.folder, _BINARY_FOLDER, file_name)
             self.files_hash[full_path] = _get_hash_md5(full_path)
 
     def _get_binary(self, ext):
         binary = []
-        for root, dirs, files in os.walk(os.path.join(self.arguments.folder, self._binary_folder)):
+        for root, dirs, files in os.walk(os.path.join(self.arguments.folder, _BINARY_FOLDER)):
             for file in files:
                 if file.endswith(ext):
                     file_name = os.path.join(root, file)
@@ -178,7 +178,7 @@ class Sync(runner1c.command.Command):
             with open(self._hash_file_name, mode='r', encoding='utf-8') as file_stream:
                 try:
                     files_hash = json.loads(file_stream.read())
-                except:
+                except json.JSONDecodeError:
                     pass
             file_stream.close()
 
@@ -188,9 +188,9 @@ class Sync(runner1c.command.Command):
 
         change_binary = []
         source_map = {}
-        self._fill_files_hash(self._get_binary('.epf'))
-        self._fill_files_hash(self._get_binary('.erf'))
-        self._fill_files_hash(self._get_binary('.feature'))
+        self._fill_files_hash(self._get_binary(_EPF_BINARY))
+        self._fill_files_hash(self._get_binary(_ERF_BINARY))
+        self._fill_files_hash(self._get_binary(_FEATURE_SRC))
 
         old_hash_file = self._read_hash_from_file()
 
@@ -200,13 +200,13 @@ class Sync(runner1c.command.Command):
 
         for file_name in change_binary:
             head, tail = os.path.split(file_name)
-            new_head = head.replace(self._binary_folder + '\\', '')
+            new_head = head.replace(_BINARY_FOLDER + '\\', '')
 
             ext = os.path.splitext(file_name)[1]
-            if ext == '.feature':
-                new_tail = tail.replace(ext, self._feature_binary)
+            if ext == _FEATURE_SRC:
+                new_tail = tail.replace(ext, _FEATURE_BINARY)
             else:
-                new_tail = tail.replace(ext, '.xml')
+                new_tail = tail.replace(ext, _DATA_SRC)
 
             source_map[file_name] = os.path.join(new_head, new_tail)
 
@@ -214,19 +214,21 @@ class Sync(runner1c.command.Command):
 
 
 def _is_header_epf(file_name):
-    with open(file_name, mode='r', encoding='utf-8-sig') as file:
-        text = file.read()
-    file.close()
-
+    text = _read_src(file_name)
     return 'ExternalDataProcessor' in text
 
 
 def _is_header_erf(file_name):
+    text = _read_src(file_name)
+    return 'ExternalReport' in text
+
+
+def _read_src(file_name):
     with open(file_name, mode='r', encoding='utf-8-sig') as file:
         text = file.read()
     file.close()
 
-    return 'ExternalReport' in text
+    return text
 
 
 def _get_hash_md5(filename):
